@@ -29,6 +29,9 @@ In addition:
    image in the age column.
  - If the person is married, it makes the background color for that row a light
    blue.
+   
+ - If this demo is running under QT, it displays each person's surname
+   in a row label.
 
 This example demonstrates:
 
@@ -45,7 +48,9 @@ Additional notes:
 """
 
 from random import randint, choice, shuffle
-from traits.api import HasTraits, Str, Int, List, Instance, Property, Constant, Color
+from traits.api import HasTraits, Str, Int, List, Instance, Property, \
+     Constant, Color
+from traits.etsconfig.api import ETSConfig
 from traitsui.api import View, Group, Item, TabularEditor
 from traitsui.tabular_adapter import TabularAdapter
 
@@ -56,6 +61,10 @@ class Person(HasTraits):
     name    = Str
     address = Str
     age     = Int
+    
+    # surname is displayed in qt-only row label:
+    surname = Property(fget=lambda self: self.name.split()[-1], 
+                       depends_on='name')
 
 #-- MarriedPerson Class Definition ---------------------------------------------
 
@@ -66,12 +75,22 @@ class MarriedPerson(Person):
 #-- Tabular Adapter Definition -------------------------------------------------
 
 class ReportAdapter(TabularAdapter):
-
+    """ The tabular adapter interfaces between the tabular editor and the data 
+    being displayed. For more details, please refer to the traitsUI user guide. 
+    """
+    # List of (Column labels, Column ID).
     columns = [ ('Name',    'name'),
                 ('Age',     'age'),
                 ('Address', 'address'),
                 ('Spouse',  'spouse') ]
 
+    row_label_name = 'surname'
+
+    # Interfacing between the model and the view: make some of the cell 
+    # attributes a property whose behavior is then controlled by the get 
+    # (and optionally set methods). The cell is identified by its column 
+    # ID (age, spouse).
+    
     # Font fails with wx in OSX; see traitsui issue #13:
     # font                      = 'Courier 10'
     age_alignment             = Constant('right')
@@ -91,9 +110,13 @@ class ReportAdapter(TabularAdapter):
 
 #-- Tabular Editor Definition --------------------------------------------------
 
+# The tabular editor works in conjunction with an adapter class, derived from 
+# TabularAdapter. 
 tabular_editor = TabularEditor(
     adapter    = ReportAdapter(),
-    operations = [ 'move' ],
+    operations = [ 'move', 'edit' ],
+    # Row titles are not supported in WX:
+    show_row_titles = ETSConfig.toolkit == 'qt4',
 )
 
 #-- Report Class Definition ----------------------------------------------------
