@@ -1,8 +1,11 @@
-#  Copyright (c) 2007, Enthought, Inc.
-#  License: BSD Style.
-
 """
-A Traits UI editor that wraps a WX timer control.
+A timer editor
+
+Display or edit a time.
+
+You can edit the time directly, or by using only the arrow keys (left & right
+to navigate, up & down to change).
+
 """
 import datetime
 
@@ -32,5 +35,3 @@ demo = TimeEditorDemo()
 
 if __name__ == "__main__":
     demo.configure_traits()
-
-#-- eof -----------------------------------------------------------------------
