@@ -131,8 +131,9 @@ class Editor ( HasPrivateTraits ):
         HasPrivateTraits.__init__( self, **traits )
         try:
             self.old_value = getattr( self.object, self.name )
-        except AttributeError, ex:
-            if ex.args[0].endswith("instance is an 'event', which is write only.") or self.name == 'spring' :
+        except AttributeError:
+            ctrait = self.object.base_trait(self.name)
+            if ctrait.type == 'event' or self.name == 'spring':
                 # Getting the attribute will fail for 'Event' traits:
                 self.old_value = Undefined
             else :
@@ -249,7 +250,7 @@ class Editor ( HasPrivateTraits ):
         return getattr( self.object, self.name, Undefined )
 
     def _set_value ( self, value ):
-        if self.name != 'None':
+        if self.ui and self.name != 'None':
             self.ui.do_undoable( self.__set_value, value )
 
     def __set_value ( self, value ):
