@@ -612,6 +612,12 @@ class ShadowGroup ( Group ):
         corresponding ShadowGroup objects.
     """
 
+    def __init__( self, shadow, **traits ):
+        # Set the 'shadow' trait before all others, to avoid exceptions
+        # when setting those other traits.
+        self.shadow = shadow
+        super( ShadowGroup, self ).__init__( **traits )
+
     #---------------------------------------------------------------------------
     # Trait definitions:
     #---------------------------------------------------------------------------
