@@ -17,8 +17,9 @@ using pickle.
 #  Imports:
 #-------------------------------------------------------------------------------
 
-from cPickle import dumps, load, loads
+from cPickle import dumps, load, loads, PickleError
 from cStringIO import StringIO
+import warnings
 
 from pyface.qt import QtCore, QtGui
 
@@ -48,30 +49,57 @@ class PyMimeData(QtCore.QMimeData):
                 # We may not be able to pickle the data.
                 try:
                     pdata = dumps(data)
-                except:
-                    return
+                    # This format (as opposed to using a single sequence) allows
+                    # the type to be extracted without unpickling the data.
+                    self.setData(self.MIME_TYPE, dumps(data.__class__) + pdata)
+                except (PickleError, TypeError):
+                    # if pickle fails, still try to create a draggable
+                    warnings.warn(("Could not pickle dragged object %s, " +
+                            "using %s mimetype instead") % (repr(data),
+                            self.NOPICKLE_MIME_TYPE), RuntimeWarning)
+                    self.setData(self.NOPICKLE_MIME_TYPE, str(id(data)))
 
-                # This format (as opposed to using a single sequence) allows the
-                # type to be extracted without unpickling the data itself.
-                self.setData(self.MIME_TYPE, dumps(data.__class__) + pdata)
         else:
             self.setData(self.NOPICKLE_MIME_TYPE, str(id(data)))
 
     @classmethod
     def coerce(cls, md):
-        """ Coerce a QMimeData instance to a PyMimeData instance if possible.
+        """ Wrap a QMimeData or a python object to a PyMimeData.
         """
         # See if the data is already of the right type.  If it is then we know
         # we are in the same process.
         if isinstance(md, cls):
             return md
 
-        # See if the data type is supported.
-        if not md.hasFormat(cls.MIME_TYPE):
-            return None
-
-        nmd = cls()
-        nmd.setData(cls.MIME_TYPE, md.data())
+        if isinstance(md, PyMimeData):
+            # if it is a PyMimeData, migrate all its data, subclasses should
+            # override this method if it doesn't do thgs correctly for them
+            data = md.instance()
+            nmd = cls()
+            nmd._local_instance = data
+            for format in md.formats():
+                nmd.setData(format, md.data(format))
+        elif isinstance(md, QtCore.QMimeData):
+            # if it is a QMimeData, migrate all its data
+            nmd = cls()
+            for format in md.formats():
+                nmd.setData(format, md.data(format))
+        else:
+            # by default, try to pickle the coerced object
+            pickle = True
+    
+            # See if the data is a list, if so check for any items which are
+            # themselves of the right type.  If so, extract the instance and
+            # track whether we should pickle.
+            # XXX lists should suffice for now, but may want other containers
+            if isinstance(md, list):
+                pickle = not any(item.hasFormat(cls.NOPICKLE_MIME_TYPE)
+                        for item in md if isinstance(item, QtCore.QMimeData))
+                md = [item.instance() if isinstance(item, PyMimeData) else item
+                        for item in md]
+    
+            # Arbitrary python object, wrap it into PyMimeData
+            nmd = cls(md, pickle)
 
         return nmd
 
@@ -81,6 +109,10 @@ class PyMimeData(QtCore.QMimeData):
         if self._local_instance is not None:
             return self._local_instance
 
+        if not self.hasFormat(self.MIME_TYPE):
+            # We have no pickled python data defined.
+            return None
+
         io = StringIO(str(self.data(self.MIME_TYPE)))
 
         try:
@@ -89,7 +121,7 @@ class PyMimeData(QtCore.QMimeData):
 
             # Recreate the instance.
             return load(io)
-        except:
+        except PickleError:
             pass
 
         return None
@@ -103,11 +135,20 @@ class PyMimeData(QtCore.QMimeData):
         try:
             if self.hasFormat(self.MIME_TYPE):
                 return loads(str(self.data(self.MIME_TYPE)))
-        except:
+        except PickleError:
             pass
 
         return None
 
+    def localPaths(self):
+        """ The list of local paths from url list, if any.
+        """
+        ret = []
+        for url in self.urls():
+            if url.scheme() == 'file':
+                ret.append(url.toLocalFile())
+        return ret
+
 #-------------------------------------------------------------------------------
 #  '_Clipboard' class:
 #-------------------------------------------------------------------------------
