@@ -3,7 +3,8 @@
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD license.
-# However, when used with the GPL version of PyQt the additional terms described in the PyQt GPL exception also apply
+# However, when used with the GPL version of PyQt the additional terms described
+# in the PyQt GPL exception also apply
 
 #
 # Author: Riverbank Computing Limited
@@ -20,7 +21,7 @@ from pyface.qt import QtCore, QtGui
 
 from pyface.api import ImageResource
 
-from traits.api import Str, Any, Bool, Dict
+from traits.api import Str, Any, Bool, Dict, Instance
 from traits.trait_base import user_name_for, enumerate, xgetattr
 
 # FIXME: ToolkitEditorFactory is a proxy class defined here just for backward
@@ -53,6 +54,10 @@ class SimpleEditor ( Editor ):
     # Is the list of items being edited mutable?
     mutable = Bool( True )
 
+    # Signal mapper allowing to identify which icon button requested a context
+    # menu
+    mapper = Instance(QtCore.QSignalMapper)
+
     #---------------------------------------------------------------------------
     #  Class constants:
     #---------------------------------------------------------------------------
@@ -105,6 +110,9 @@ class SimpleEditor ( Editor ):
         self.control.setFrameShape(QtGui.QFrame.NoFrame)
         self.control.setWidgetResizable(True)
 
+        #Create a mapper to identify which icon button requested a contextmenu
+        self.mapper = QtCore.QSignalMapper(self.control)
+
         # Create a widget with a grid layout as the container.
         self._list_pane = QtGui.QWidget()
         self._list_pane.setSizePolicy(QtGui.QSizePolicy.Expanding,
@@ -152,6 +160,7 @@ class SimpleEditor ( Editor ):
         """ Updates the editor when the object trait changes externally to the
             editor.
         """
+        self.mapper = QtCore.QSignalMapper(self.control)
         # Disconnect the editor from any control about to be destroyed:
         self._dispose_items()
 
@@ -166,7 +175,10 @@ class SimpleEditor ( Editor ):
 
         is_fake = (resizable and (len( self.value ) == 0))
         if is_fake:
-           self.empty_list()
+            self.empty_list()
+        else:
+            # Asking the mapper to send the sender to the callback method
+            self.mapper.mapped[QtCore.QObject].connect(self.popup_menu)
 
         editor = self._editor
         for index, value in enumerate(self.value):
@@ -177,7 +189,12 @@ class SimpleEditor ( Editor ):
             column = column * 2
 
             if resizable:
-                control = IconButton('list_editor.png', self.popup_menu)
+                # Connecting the new button to the mapper
+                control = IconButton('list_editor.png', self.mapper.map)
+                # Setting the mapping and asking it to send the index of the
+                # sender to the callback method
+                self.mapper.setMapping(control, control)
+
                 layout.addWidget(control, row, column)
 
             proxy = ListItemProxy( self.object, self.name, index, item_trait,
@@ -232,7 +249,12 @@ class SimpleEditor ( Editor ):
     def empty_list ( self ):
         """ Creates an empty list entry (so the user can add a new item).
         """
-        control = IconButton('list_editor.png', self.popup_empty_menu)
+        # Connecting the new button to the mapper
+        control = IconButton('list_editor.png', self.mapper.map)
+        # Setting the mapping and asking it to send the sender to the
+        # callback method
+        self.mapper.setMapping(control, control)
+        self.mapper.mapped[QtCore.QObject].connect(self.popup_empty_menu)
         control.is_empty = True
         self._cur_control = control
 
@@ -258,10 +280,10 @@ class SimpleEditor ( Editor ):
     #  Displays the empty list editor popup menu:
     #---------------------------------------------------------------------------
 
-    def popup_empty_menu ( self ):
+    def popup_empty_menu ( self , sender):
         """ Displays the empty list editor popup menu.
         """
-        self._cur_control = control = self.control.sender()
+        self._cur_control = control = sender
         menu = MakeMenu( self.empty_list_menu, self, True, control ).menu
         menu.exec_(control.mapToGlobal(QtCore.QPoint(0, 0)))
 
@@ -269,12 +291,9 @@ class SimpleEditor ( Editor ):
     #  Displays the list editor popup menu:
     #---------------------------------------------------------------------------
 
-    def popup_menu ( self ):
+    def popup_menu ( self , sender):
         """ Displays the list editor popup menu.
         """
-        layout = self._list_pane.layout()
-        sender = layout.sender()
-
         self._cur_control = sender
 
         proxy    = sender.proxy
@@ -569,6 +588,9 @@ class NotebookEditor ( Editor ):
             # Remember the page for later deletion processing:
             self._uis.append([ui.control, ui, view_object, monitoring])
 
+        if self.selected:
+            self._selected_changed(self.selected)
+
     #---------------------------------------------------------------------------
     #  Handles some subset of the trait's list being updated:
     #---------------------------------------------------------------------------
